/*-------------------------------------------------------------------------------------------------------------+
|                                                                                                              |
|   Trigger: CANCELA_ATIVIDADE_PROJETO                                                                         |
|   Tabelas: PLANATIVTARE e TAREFA                                                                             |
|                                                                                                              |
|   Descrio:                                                                                                 |
|   Altera a tabela PLANATIVTARE (Planejamento de atividade da tarefa), mudando o valor do campo IDSITATIVTAR  |
|   (Identificador da situao da atividade da tarefa) para 'X' (cancelada) caso seu valor atual seja 'I'      |
|   (interrompida) e o projeto referente  respectiva atividade j tenha sido concludo ou cancelado           |
|   (tabela PROJETO, campo IDSITPROJETO = 'C' ou 'E') e a solicitao referente a tal atividade esteja         |
|   encerrada (tabela SOLISERV, campo IDSOLIENCE = 'S'). Caso o campo IDSITATIVTAR da tabela PLANATIVTARE      |
|   esteja com o valor 'P' (pendente) e as condies anteriores forem atendidas (menos IDSITATIVTAR = 'I'),    |
|   o registro da atividade ser apagado. As tarefas (tabela TAREFA) relativas s atividades canceladas        |
|   tambm sero canceladas, mudando o valor do campo IDSITTAREFA (Identificador da situao da                |
|   tarefa) para 'X' (cancelada). Um projeto pode ter uma ou vrias solicitaes, uma solicitao pode ter     |
|   uma ou vrias tarefas e cada tarefa pode ter uma ou vrias atividades.                                     |
|                                                                                                              |
|   Ref. solicitao: 62321                                                                                    |
|                                                                                                              |
|                                                                                                              |
|   Criao:                                                                                                   |
|   28/11/2008 - Ronald Reis                                                                                   |
|                                                                                                              |
+-------------------------------------------------------------------------------------------------------------*/

CREATE OR REPLACE TRIGGER CANCELA_ATIVIDADE_PROJETO
AFTER UPDATE
OF IDSITPROJETO ON PROJETO FOR EACH ROW

BEGIN

   IF (:NEW.IDSITPROJETO = 'E') OR (:NEW.IDSITPROJETO = 'C') THEN

      FOR C_SOLICITACAO IN (SELECT SOL.NRSOLISERV, SBL.CDFILIAL
                              FROM SOLISERV SOL, SOLIBASELINE SBL
                             WHERE SBL.CDPROJETO  = :NEW.CDPROJETO  AND
                                   SOL.CDFILIAL   = SBL.CDFILIAL AND                                   
                                   SOL.NRSOLISERV = SBL.NRSOLISERV AND
                                   SOL.IDSOLIENCE = 'S') LOOP

         FOR C_TAREFA IN (SELECT NRTAREFA
                       FROM TAREFA
                       WHERE NRSOLISERV = C_SOLICITACAO.NRSOLISERV AND
                             CDFILIAL   = C_SOLICITACAO.CDFILIAL) LOOP
            
            UPDATE PLANATIVTARE SET
            IDSITATIVTAR = 'X'
            WHERE IDSITATIVTAR = 'I'   AND
                  CDFILIAL = C_SOLICITACAO.CDFILIAL AND
                  NRTAREFA = C_TAREFA.NRTAREFA;

            UPDATE TAREFA SET
            IDSITTAREFA = 'X'
            WHERE CDFILIAL = C_SOLICITACAO.CDFILIAL AND
                  NRTAREFA = C_TAREFA.NRTAREFA;

            DELETE FROM PLANATIVTARE
            WHERE IDSITATIVTAR = 'P' AND
                  CDFILIAL = C_SOLICITACAO.CDFILIAL AND
                  NRTAREFA = C_TAREFA.NRTAREFA;
         END LOOP;

      END LOOP;

   END IF;

END;
/

-- VERSAO --
BEGIN ATUVEROBJ('CANCELA_ATIVIDADE_PROJETO','5.10.015'); END;
/
